//-----------------------------------------------------------
//          LimitBreakUtil                                   <br />
//                                                           <br />
//          Utility Class for working around RPGAbilities
//          static funcitons. Most of the functionality
//          is in this class.                                <br />
//                                                           <br />
//          Author: Continuum                                <br />
//
//-----------------------------------------------------------
class LimitBreakUtil  extends Object config(UT2004RPG);


/*
   04Mar2007
   Variables need to be gone through again... some aren't
   usefull and others have bad descriptions.

*/


/** Length of lvl 1 limit break. <br />
    Higher lvls of limit break may add
    aditional time? */
var config float breakLength;


/** Percentage of pawn lvl for adjusting amount of points based on players current level. */
var config float lvlFactor;

/** Minimum number of limit points needed to reach a limit break. */
var config int minLimitPoints;
/** Maximum number of limit points needed to reach a limit break. */
var config int maxLimitPoints;



/** Percentage for adjusting amount of points based on damage. <br /> not used by default*/
var config float damageFactor;

/** Used when pawns health percentage of SuperMaxHealth is greater than hpHighest_PercOfSuperMax. */
var config float hpHighest_Factor;
/** Percentage of SuperMaxHealth it takes for the hpHighest_Factor to be used.*/
var config float hpHighest_PercOfSuperMax;

/** Used when pawns health percentage of SuperMaxHealth is greater than hpHigh_PercOfSuperMax. */
var config float hpHigh_Factor;
/** Percentage of SuperMaxHealth it takes for the hpHigh_Factor to be used.*/
var config float hpHigh_PercOfSuperMax;

/** Used when pawns health percentage of SuperMaxHealth is greater than hpLow_PercOfSuperMax. */
var config float hpLow_Factor;
/** Percentage of SuperMaxHealth it takes for the hpLow_Factor to be used.*/
var config float hpLow_PercOfSuperMax;

/** Used when pawns health percentage of SuperMaxHealth is greater than hpHighest_PercOfSuperMax. */
var config float hpCritical_Factor;
/** Percentage of SuperMaxHealth it takes for the hpHighest_Factor to be used.*/
var config float hpCritical_PercOfSuperMax;

/** Used when pawns health is full - nearly full */
var config float hpFull_Factor;



/** Used with lvlFactor when player has less than 15% max Health. */
var config float hpCritical;




/** Number of points needed for pawns limit break to be reached. */
var float playersLimitBreak;
/** Current number of limit points the player has. */
var float limitPoints;
/** true while players limitPoints == playersLimitBreak && countdown > 0 */
var bool isLimit;
/** The players level. */
var int playerLvl;
/** The players limit break lvl. */
var int limitLvl;
/** Calculated from pawns current (health, max health, matched to hpFull - hpCritical ranges). */
var float healthFactor;
/** Calculated from (lvlFactor, pawns level) & (pawns.Health, healthFactor) & (Damage) */
var float pointFactor;


var int abilityLvl;
/**
  Calculates the healthFactor used in limitPoint calculation.<br />
  <ul>
      <li>@param health Injured.Health</li>
      <li>@param maxHealth Injured.SuperMaxHealth</li>

  </ul>

  <br />
  <i>
     11Mar2007   <br />
     Somehow healthFactor is always 1.00 unsure why.
  </i>


*/
function calcHealthFactor(float health, float superMaxHealth)
{
   local float percOfSuperMax;

   healthFactor = 0.00;
   percOfSuperMax = health / superMaxHealth;

   if(percOfSuperMax > 0 && percOfSuperMax < (hpCritical_PercOfSuperMax * superMaxHealth))
   {
    healthFactor = hpCritical_Factor;
    log("Health Critical");
   }
   else if(percOfSuperMax < (hpLow_PercOfSuperMax * superMaxHealth))
   {
    healthFactor = hpLow_Factor;
    log("Health Low");
   }
   else if(percOfSuperMax < (hpHigh_PercOfSuperMax * superMaxHealth))
   {
    healthFactor = hpHigh_Factor;
    log("Health High");
   }
   else if(percOfSuperMax < (hpHighest_PercOfSuperMax * superMaxHealth))
   {
    healthFactor = hpHighest_Factor;
    log("Health Highest");
   }
   else
   {
    healthFactor = hpFull_Factor;
    log("Health full");
   }



   log("!!!!!! LimitBreak percent of max health is " $ percOfSuperMax $ " health Factor is " $ healthFactor);



}//calcHealthFactor()


/**
   Calculates the actuall limitPoints given to the pawn
   from recieving damage.
*/
function calcPoints(Pawn p, int Damage)
{

 local AbilityLimitBreak ab;
 local RPGPlayerManip playerManip;

 playerManip = new class'RPGPlayerManip';
 ab = new class'AbilityLimitBreak';
 abilityLvl = playerManip.getRPGPlayerAbilityLvl(p, ab);//need ability lvl
 playerLvl = playerManip.getRPGPlayerLvl(p);//need players level

 /*
   (1 to 3) * ((0.15 to 1.00) * Damage) / (playerLvl * lvlFactor))

   example 1
           abilityLvl = 3, healthFactor = 0.50, Damage = 30, playerLvl = 100, lvlFactor = 0.60
           limitPoints =  0.45

 */

 log("!!!!!! LimitBreak calculating points");
 log("limitPoints : " $ limitPoints);
 log("abilityLvl  : " $ abilityLvl);
 log("healthFactor: " $ healthFactor);
 log("Damage      : " $ Damage);
 log("playerLvl   : " $ playerLvl);
 log("______________________________");
 log(limitPoints + (abilityLvl * ((healthFactor * Damage)/ (playerLvl * lvlFactor))));

 limitPoints = limitPoints + (abilityLvl * ((healthFactor * Damage) / (playerLvl * lvlFactor)));

 log("!!!!!!!!!!!!LimitBreak Points: " $ limitPoints $ " !!!!!!!!!");
 if(limitPoints >= playersLimitBreak)
 {
  log("!!!!!! LimitBreak isLimit is true");
  isLimit = true;
 }

}//calcPoints()


DefaultProperties
{


    hpHighest_Factor=0.15
    hpHighest_PercOfSuperMax=0.80
    hpHigh_Factor=0.50
    hpHigh_PercOfSuperMax=0.75
    hpLow_Factor=0.70
    hpLow_PercOfSuperMax=0.15
    hpCritical_Factor=1.00
    hpCritical_PercOfSuperMax=0.08
    hpFull_Factor=0.01
    breakLength=5
    playersLimitBreak=20
    lvlFactor=0.60
    damageFactor=0.10
    minLimitPoints=100
    maxLimitPoints=2000
}
