//-----------------------------------------------------------
//          RPGPlayerManip                                   <br />
//                                                           <br />
//          Utility Class for manipulating the RPG Players
//          Temporary package untill more utilities are
//          created.                                         <br />
//                                                           <br />
//          Author: Continuum                                <br />
//
//-----------------------------------------------------------
class RPGPlayerManip  extends Object;


/**
   Cycle through pawns inventory and find the RPGPlayerDataObject in it,
   Return the RPGPlayerDataObject.
   <ul>
       <li>@param Pawn The pawn to look in.</li>
   </ul>

   <br />
   <b>Note</b><br />
   <i>The RPGPlayerDataObject that is returned from this method is initialized to
   none so check if it == none before using.</i>
*/
static function RPGPlayerDataObject getRPGPlayerData(Pawn p)
{


 local RPGStatsInv StatsInv;
 local RPGPlayerDataObject rpgPlayer;


 /*
   If no controller or not a player do not continue.
 */
 if (p.Controller == None || !p.Controller.bIsPlayer)
 {
  log("!!!!!! LimitBreak getRPGPlayer returning none (p.Controller == none || !p.Controller.bIsPlayer)");
  return none;
 }//if


 StatsInv = RPGStatsInv(p.FindInventoryType(class'RPGStatsInv'));//Find the RPGStatsInv object in the pawns inventory

 if (StatsInv != None)
 {
    rpgPlayer = StatsInv.DataObject;
    log("!!!!!! LimitBreak getRPGPlayer should return a dataobject");
 }


 return rpgPlayer;//check for null when calling



}//getRpgPlayerData()


/**
  Returns the level of an RPGPlayer.
  <ul>
      <li>@param p The pawn</li>
  </ul>
*/
static function int getRPGPlayerLvl(Pawn p)
{
       local RPGPlayerDataObject rpgPlayer;
       local int playerLvl;

       playerLvl = 0;
       rpgPlayer = getRPGPlayerData(p);
       if(rpgPlayer == none)
       {
        log("!!!!!! LimitBreak RPGPlayerManip.getRPGPlayerLvl() did not return a RPGPLayerDataObject!");
        return -1;
       }
       else
       {
        playerLvl = rpgPlayer.Level;
        log("!!!!!! LimitBreak getRPGPlayerLvl " $ playerLvl);
        return playerLvl;
       }

}//getRPGPlayerLvl()


/**
   Get the lvl of an ability.<br />
   <ul>
       <li>@param p Pawn wanting their ability lvl</li>
       <li>@param ability The ability that the lvl is needed for</li>
   </ul>
   <br />
   <i>Edit<br />
   No suitable static properties or functions could be used for this so this
   function no longer uses RPGAbility as the 2nd Parameter... RPGAbility needs
   a static name or id field for this to work properly.</i>
*/
static function int getRPGPlayerAbilityLvl(Pawn p, AbilityLimitBreak ability)
{
       local RPGPlayerDataObject rpgPlayer;
       local int abilityLvl;
       local int i;

       rpgPlayer = getRPGPlayerData(p);
       log("!!!!!! LimitBreak looking for ability level for " $ ability.abilityName());

       log("!!!!!! LimitBreak rpgPlayer.Abilities.length " $ rpgPlayer.Abilities.Length);


       for(i = 0; i < rpgPlayer.Abilities.length; i++)
       {
          log("!!!!!! LimitBreak looping through rpgPlayer.Abilities[] loop #" $i);

       /*
         In the future re-write to be <br />
         if(rpgPlayer.Abilities.static.abilityName == ability.abilityName)
         RPGAbility needs to have a static field abilityName to use this.
       */
        if(rpgPlayer.Abilities[i] == ability.class)
        {
           abilityLvl = rpgPlayer.AbilityLevels[i];
           log("!!!!!! LimitBreak Abilityfound, abilityLvl is " $ rpgPlayer.AbilityLevels[i]);
        }



       }

       return abilityLvl;

}//getRPGPLayerAbilityLvl()

/**
  Test if item is in pawns inventory. Optionally create the item if it
  is not found.
  <ul>
      <li>@param p Pawn reference.</li>
      <li>@param invName class name of inventory to find</li>
      <li>@param doCreate optionally create the inventory item if it is not found.
  </ul>
*/
static function bool isInInventory(Pawn p, coerce string invName, optional bool doCreate)
{
       local class<Inventory> temp;
       local Inventory inv;
       temp = class<Inventory>(DynamicLoadObject(invName, class'Class'));

       if(temp == none)
       {

         log("!!!!!! LimitBreak failed to load inventory! returning false");
         return false;//something is wrong
       }
       else
       {
        inv = p.FindInventoryType(temp.class);
        log("!!!!!! LimitBreak Inventory found returning true");
        return true;//item found

        /*
           Item was not found, spawn a new invetory
           item add it to the pawns inventory and return it.
         */
         if(inv == none && doCreate == true)
         {

                inv = p.spawn(class'LimitBreakInv');//ruins idea behind this function
                p.AddInventory(inv);
                //p.CreateInventory(invName);
                //p.AddInventory(temp);//pawn now has an instance of that inventory item

                inv = p.FindInventoryType(temp.class);
                log("!!!!!! LimitBreak Inventory not found creating Inventory.. returning true");
                return true;//item created


         }
         log("!!!!!! LimitBreak unknown error finding inventory returning false");
         return false;//should not be reached

       }


}//isInInventory()




